#include "led_blinkwindow.h"
#include "ui_led_blinkwindow.h"
#include <iostream>
#include <qdebug.h>

using namespace std;
LED_BlinkWindow::LED_BlinkWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::LED_BlinkWindow)
{
    initLEDs();
    ui->setupUi(this);
    /*
     * timer for blinking the LED
     */
    timer = new QTimer();
    timer->setSingleShot(true);
    connect(ui->greenLEDSlider,SIGNAL(valueChanged(int)),this,SLOT(setIntensity()));
    connect(ui->redLEDSlider,SIGNAL(valueChanged(int)),this,SLOT(setBlinkSpeed()));
    connect(timer,SIGNAL(timeout()),this,SLOT(switchRedLED()));
    gpio_write(pi,RED_LED,OFF);
    gpio_write(pi,GREEN_LED,OFF);
    greenLEDState=OFF;

}

LED_BlinkWindow::~LED_BlinkWindow()
{
    delete ui;
}

void LED_BlinkWindow::on_actionQuit_triggered() {
    gpio_write(pi,RED_LED,OFF);
    gpio_write(pi,GREEN_LED,OFF);
    pigpio_stop(pi);
}

int LED_BlinkWindow::initLEDs() {

    if ((retCode = pigpio_start("openday-05",(char *)NULL)) < 0) {
      printf("ledInit: Could not open the connection to the pigpio daemon\n");
      return retCode;
    }
    pi = retCode;
    qDebug() << "pi: " << pi << endl;

    if ((retCode = set_mode(pi,GREEN_LED,PI_OUTPUT)) < 0) {
      qDebug() << "ledInit: Could not set green LED to output\n" << retCode <<endl;
      gpio_write(pi,GREEN_LED,0);
      return retCode;
    }

    if ((retCode = set_mode(pi,RED_LED,PI_OUTPUT)) < 0) {
      qDebug() << "ledInit: Could not set red LED to output\n" << endl;
      gpio_write(pi,RED_LED,0);
      return retCode;
    }
    return 0;
}

    void LED_BlinkWindow::setBlinkSpeed() {
        int blinkValue = ui->redLEDSlider->value();
//        qDebug() << "red slider blink speed value: " << blinkValue;
        if(blinkValue == 99) {
            gpio_write(pi,RED_LED,ON);
            ui->redLED->setPixmap(QPixmap(":/icons/icons/led-red-on-md.png"));
            qDebug() << "set to on and stop timer";
            timer->stop();
        }
        else if (blinkValue == 0) {
            gpio_write(pi,RED_LED,OFF);
            ui->redLED->setPixmap(QPixmap(":/icons/icons/led-red-off-md.png"));
            qDebug() << "set to off and stop timer";
                timer->stop();
        }
        else {
            blinkSpeed=(100-blinkValue)*10;
            timer->start(blinkSpeed);
        }
    }

void LED_BlinkWindow::setIntensity() {
    int intensity = ui->greenLEDSlider->value();
//    qDebug() << "green slider intensity value: " << intensity;
    if (set_PWM_dutycycle(pi,GREEN_LED,intensity*2) < 0)
        qDebug() << "cannot set duty cycle to " << (int)round((double)intensity * 2.55);
    int iconNo = 12 -(int)round((double)intensity*12.0/99.0);
    qDebug() << "Icon No: " << iconNo;
    ui->greenLed->setPixmap(greenIcons[iconNo]);
}

void LED_BlinkWindow::switchRedLED() {
    if(greenLEDState) {
        gpio_write(pi,RED_LED,OFF);
        greenLEDState=OFF;
        ui->redLED->setPixmap(QPixmap(":/icons/icons/led-red-off-md.png"));
    }
    else {
        gpio_write(pi,RED_LED,ON);
        greenLEDState=ON;
        ui->redLED->setPixmap(QPixmap(":/icons/icons/led-red-on-md.png"));
    }
    timer->start(blinkSpeed);
}
