#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "qdebug.h"

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    initLEDs();
    ui->setupUi(this);

    connect(ui->greenLEDSwitch,SIGNAL(clicked()),this,SLOT(greenLEDActivate()));
    connect(ui->redLEDSwitch,SIGNAL(clicked()),this,SLOT(redLEDActivate()));
    greenLEDState=false;
    redLEDState=false;
    gpio_write(pi,RED_LED,OFF);
    gpio_write(pi,GREEN_LED,OFF);
}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::on_actionQuit_triggered()
{
    exit(0);
}

void MainWindow::greenLEDActivate() {
    qDebug() << "activate green LED" << endl;
    if (greenLEDState) {
        greenLEDState =false;
        ui->greenLED->setPixmap(QPixmap(":/icons/icons/led-green-off-md.png"));
        gpio_write(pi,GREEN_LED,OFF);
    }
    else {
        greenLEDState =true;
        ui->greenLED->setPixmap(QPixmap(":/icons/icons/led-green-on-md.png"));
        gpio_write(pi,GREEN_LED,ON);
    }

}
void MainWindow::redLEDActivate() {
    qDebug() << "activate red LED" << endl;
    if (redLEDState) {
        redLEDState =false;
        ui->redLED->setPixmap(QPixmap(":/icons/icons/led-red-off-md.png"));
        gpio_write(pi,RED_LED,OFF);
    }
    else {
        redLEDState =true;
        ui->redLED->setPixmap(QPixmap(":/icons/icons/led-red-on-md.png"));
        gpio_write(pi,RED_LED,ON);
    }
}

int MainWindow::initLEDs() {

    if ((retCode = pigpio_start("openday-05",(char *) NULL)) < 0) {
      printf("ledInit: Could not open the connection to the pigpio daemon\n");
      return retCode;
    }
    pi = retCode;
    qDebug() << "pi: " << pi << endl;

    if ((retCode = set_mode(pi,GREEN_LED,PI_OUTPUT)) < 0) {
      qDebug() << "ledInit: Could not set green LED to output\n" << retCode <<endl;
      gpio_write(pi,GREEN_LED,0);
      return retCode;
    }

    if ((retCode = set_mode(pi,RED_LED,PI_OUTPUT)) < 0) {
      qDebug() << "ledInit: Could not set red LED to output\n" << endl;
      gpio_write(pi,RED_LED,0);
      return retCode;
    }
    return 0;
}
